server_client_20141211_175217

### config1 : test_ordered_events

Result | Function execution time | Total execution time
--- | --- | ---
Passed | 1.15796899796 sec | 3.40887999535 sec

Naarad report

### Metrics

#### server1-perf

Submetric | max | mean | min | p50 | p75 | p90 | p95 | p99 | std
--- | --- | --- | --- | --- | --- | --- | --- | --- | ---
latency | 0.28 | 0.22 | 0.19 | 0.2 | 0.22 | 0.25 | 0.27 | 0.27 | 0.036
qps | 4.00 | 4.00 | 4.00 | 4.00 | 4.00 | 4.00 | 4.00 | 4.00 | 0.0

#### client1-perf

Submetric | max | mean | min | p50 | p75 | p90 | p95 | p99 | std
--- | --- | --- | --- | --- | --- | --- | --- | --- | ---
latency | 22.95 | 22.95 | 22.95 | 22.95 | 22.95 | 22.95 | 22.95 | 22.95 | 0.0
qps | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 0.0

### SLAs

metric | submetric | sla rule | value
--- | --- | --- | ---
server1-perf | latency | p50 lt 0.3 | 0.1955
server1-perf | latency | mean lt 0.33 | 0.21525
server1-perf | qps | mean lt 7.0 | 4.0
server2-perf | latency | p50 lt 0.3 | None
server2-perf | latency | mean lt 0.33 | None
server2-perf | qps | mean lt 7.0 | None
server3-perf | latency | p50 lt 0.3 | None
server3-perf | latency | mean lt 0.33 | None
server3-perf | qps | mean lt 7.0 | None
client1-perf | latency | p50 lt 22.0 | 22.952
client1-perf | latency | mean lt 35.0 | 22.952
client1-perf | qps | mean lt 2.0 | 1.0
client2-perf | latency | p50 lt 22.0 | None
client2-perf | latency | mean lt 35.0 | None
client2-perf | qps | mean lt 2.0 | None